@@ -10,13 +10,13 @@ function(object, ...)
   {
     cat("\n---------\n")
     cat("\nVariable:",colnames(object$dframe[i]))
-    cat("\nCategory loadings:\n")
+    cat("\nLoadings:\n")
     print(round(object$cat.loadings[[i]], 4))
     cat("\nCategory centroids:\n")
     print(round(object$cat.centroids[[i]], 4))
     cat("\nRank-restricted category quantifications:\n")
     print(round(object$rank.cat[[i]], 4)) 
-    cat("\nLower rank quantifications (rank =",object$rank.vec[i],"):\n",sep="")
+    cat("\nLower rank quantifications (rank = ",object$rank.vec[i],"):\n",sep="")
     print(round(object$low.rank[[i]], 4)) 
   }
   cat("\n")
